@@ -13,33 +13,16 @@ from __future__ import absolute_import, division, unicode_literals
 
 import logging
 
-from mo_logs.strings import expand_template
-
+from mo_kwargs import override
 from mo_dots import unwrap, Null
 from mo_logs import Log
-from mo_logs.exceptions import suppress_exception
 from mo_logs.log_usingNothing import StructuredLogger
-from mo_logs.log_usingThreadedStream import StructuredLogger_usingThreadedStream, time_delta_pusher
-
-_THREAD_STOP, _Queue, _Thread = [Null] * 3  # IMPORTS
-
-
-def _late_import():
-    global _THREAD_STOP
-    global _Queue
-    global _Thread
-
-    from mo_threads import THREAD_STOP as _THREAD_STOP
-    from mo_threads import Queue as _Queue
-    from mo_threads import Thread as _Thread
-
-    _ = _THREAD_STOP
-    _ = _Queue
-    _ = _Thread
+from mo_logs.strings import expand_template
 
 
 # WRAP PYTHON CLASSIC logger OBJECTS
 class StructuredLogger_usingHandler(StructuredLogger):
+    @override("setings")
     def __init__(self, settings):
         if not _Thread:
             _late_import()
@@ -69,11 +52,7 @@ def make_log_from_settings(settings):
         temp = __import__(path, globals(), locals(), [class_name], 0)
         constructor = object.__getattribute__(temp, class_name)
     except Exception as e:
-        if settings.stream and not constructor:
-            # PROVIDE A DEFAULT STREAM HANLDER
-            constructor = StructuredLogger_usingThreadedStream
-        else:
-            Log.error("Can not find class {{class}}",  {"class": path}, cause=e)
+        Log.error("Can not find class {{class}}",  {"class": path}, cause=e)
 
     # IF WE NEED A FILE, MAKE SURE DIRECTORY EXISTS
     if settings.filename != None:
@@ -84,6 +63,29 @@ def make_log_from_settings(settings):
             f.parent.create()
 
     settings['class'] = None
+    settings['cls'] = None
+    settings['log_type'] = None
+    settings['settings'] = None
     params = unwrap(settings)
-    log_instance = constructor(**params)
-    return log_instance
+    try:
+        log_instance = constructor(**params)
+        return log_instance
+    except Exception as cause:
+        Log.error("problem with making handler", cause=cause)
+
+
+_THREAD_STOP, _Queue, _Thread = [Null] * 3  # IMPORTS
+
+
+def _late_import():
+    global _THREAD_STOP
+    global _Queue
+    global _Thread
+
+    from mo_threads import THREAD_STOP as _THREAD_STOP
+    from mo_threads import Queue as _Queue
+    from mo_threads import Thread as _Thread
+
+    _ = _THREAD_STOP
+    _ = _Queue
+    _ = _Thread
